@@ -18,7 +18,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -765,6 +765,49 @@ dbus_g_bus_get (DBusBusType     type,
   return DBUS_G_CONNECTION_FROM_CONNECTION (connection);
 }
 
+/**
+ * dbus_g_bus_get_private:
+ * @type: bus type
+ * @context: Mainloop context to attach to
+ * @error: address where an error can be returned.
+ *
+ * Returns a connection to the given bus. The connection will be a private
+ * non-shared connection and should be closed when usage is complete.
+ * 
+ * Internally this function calls dbus_bus_get_private() then calls
+ * dbus_connection_setup_with_g_main() on the result; see the documentation
+ * of the former function for more information on private connections.
+ *
+ * Returns: a DBusConnection
+ */
+DBusGConnection*
+dbus_g_bus_get_private (DBusBusType     type,
+                        GMainContext   *context,
+                        GError        **error)
+{
+  DBusConnection *connection;
+  DBusError derror;
+
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+  _dbus_g_value_types_init ();
+
+  dbus_error_init (&derror);
+
+  connection = dbus_bus_get_private (type, &derror);
+  if (connection == NULL)
+    {
+      dbus_set_g_error (error, &derror);
+      dbus_error_free (&derror);
+      return NULL;
+    }
+
+  /* does nothing if it's already been done */
+  dbus_connection_setup_with_g_main (connection, context);
+
+  return DBUS_G_CONNECTION_FROM_CONNECTION (connection);
+}
+
 /** @} */ /* end of public API */
 
 #ifdef DBUS_BUILD_TESTS
