@@ -15,6 +15,7 @@ static const char *await_terminating_service = NULL;
 static int n_times_foo_received = 0;
 static int n_times_frobnicate_received = 0;
 static int n_times_frobnicate_received_2 = 0;
+static int n_times_compat_frobnicate_received = 0;
 static int n_times_sig0_received = 0;
 static int n_times_sig1_received = 0;
 static int n_times_sig2_received = 0;
@@ -138,6 +139,20 @@ frobnicate_signal_handler_2 (DBusGProxy  *proxy,
   g_print ("Got Frobnicate signal (again)\n");
 }
 
+static void
+frobnicate_signal_handler_compat (DBusGProxy  *proxy,
+                                  int          val,
+                                  void        *user_data)
+{
+  n_times_compat_frobnicate_received += 1;
+
+  g_assert (val == 42);
+  g_print ("Got Frobnicate signal (compat)\n");
+
+  g_main_loop_quit (loop);
+  g_source_remove (exit_timeout);
+}
+
 static void
 sig0_signal_handler (DBusGProxy  *proxy,
 		     const char  *str0,
@@ -768,6 +783,19 @@ main (int argc, char **argv)
   g_print ("ThrowError failed (as expected) returned error: %s\n", error->message);
   g_clear_error (&error);
 
+  g_print ("Calling ThrowNotSupported\n");
+  if (dbus_g_proxy_call (proxy, "ThrowNotSupported", &error,
+			 G_TYPE_INVALID, G_TYPE_INVALID) != FALSE)
+    lose ("ThrowNotSupported call unexpectedly succeeded!");
+
+  if (error->domain != DBUS_GERROR || error->code != DBUS_GERROR_NOT_SUPPORTED)
+    lose ("ThrowNotSupported call returned unexpected error: %s #%u: %s %s",
+          g_quark_to_string (error->domain), error->code,
+          dbus_g_error_get_name (error), error->message);
+
+  g_print ("ThrowNotSupported correctly returned error: %s\n", error->message);
+  g_clear_error (&error);
+
   g_print ("Calling IncrementRetvalError (for error)\n");
   error = NULL;
   v_UINT32_2 = 0;
@@ -1399,7 +1427,7 @@ main (int argc, char **argv)
 
     variant = g_new0 (GValue, 1);
     g_value_init (variant, dbus_g_type_get_collection ("GArray", G_TYPE_INT));
-    g_value_set_boxed_take_ownership (variant, array);
+    g_value_take_boxed (variant, array);
 
     if (!dbus_g_proxy_call (proxy, "ProcessVariantOfArrayOfInts123", &error,
                             G_TYPE_VALUE, variant,
@@ -1873,6 +1901,32 @@ main (int argc, char **argv)
 
   run_mainloop ();
 
+  /* Tests for a "compatibilty" object path.  This is the same object as above, just
+   * at a different path.
+   */
+  proxy = dbus_g_proxy_new_for_name_owner (connection,
+                                           "org.freedesktop.DBus.GLib.TestService",
+                                           "/org/freedesktop/DBus/GLib/Tests/Compat/MyTestObjectCompat",
+                                           "org.freedesktop.DBus.GLib.Tests.MyObject",
+                                           &error);
+  dbus_g_proxy_add_signal (proxy, "Frobnicate", G_TYPE_INT, G_TYPE_INVALID);
+
+  dbus_g_proxy_connect_signal (proxy, "Frobnicate",
+                               G_CALLBACK (frobnicate_signal_handler_compat),
+                               NULL, NULL);
+
+  g_print ("Calling EmitFrobnicate (compat)\n");
+  if (!dbus_g_proxy_call (proxy, "EmitFrobnicate", &error,
+                          G_TYPE_INVALID, G_TYPE_INVALID))
+    lose_gerror ("Failed to complete EmitFrobnicate call on compat proxy", error);
+
+  g_main_loop_run (loop);
+
+  if (n_times_compat_frobnicate_received != 1)
+    lose ("Frobnicate signal received %d times for compat proxy, should have been 1", n_times_compat_frobnicate_received);
+
+  g_object_unref (proxy);
+
   /* Test introspection */
   proxy = dbus_g_proxy_new_for_name_owner (connection,
                                            "org.freedesktop.DBus.GLib.TestService",
@@ -2069,6 +2123,27 @@ main (int argc, char **argv)
     lose ("Duplicate proxy wasn'tdestroyed");
 
   g_print ("Proxy and duplicate destroyed successfully\n");
+  
+  g_print ("Beginning private connection tests\n");
+  
+  {
+    DBusGConnection *privconn = dbus_g_bus_get_private (DBUS_BUS_SESSION, NULL, &error);
+    
+    if (privconn == NULL)
+      lose_gerror ("Failed to open private connection to bus", error);
+    g_assert (privconn != connection);
+    
+    proxy = dbus_g_proxy_new_for_name (privconn,
+                                       "org.freedesktop.DBus.GLib.TestService",
+                                       "/org/freedesktop/DBus/GLib/Tests/MyTestObject",
+                                       "org.freedesktop.DBus.GLib.Tests.MyObject");
+    
+    g_print ("[private connection] Calling (wrapped) do_nothing\n");
+    if (!org_freedesktop_DBus_GLib_Tests_MyObject_do_nothing (proxy, &error))
+      lose_gerror ("Failed to complete (wrapped) DoNothing call", error);
+    
+    g_object_unref (G_OBJECT (proxy));
+  }
 
   g_object_unref (G_OBJECT (driver));
 
